# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`lvmconf`](#lvmconf): Performs basic management of LVM in a RedHat environment.
* [`lvmconf::config`](#lvmconfconfig): Enforces lvm.conf based on lvmconf mode flags
* [`lvmconf::install`](#lvmconfinstall): Install the lvm package if specified
* [`lvmconf::service`](#lvmconfservice): Manage the state of each LVM related service based on lvmconf mode

**Resource types**

* [`lvm_config`](#lvm_config): Type to manage entries in the `/etc/lvm/lvm.conf` config file via the lvmconfig (aka lvm config) command.  Example:  ```puppet lvm_config { '

## Classes

### lvmconf

Ensures that LVM is configured correctly on each

#### Examples

##### Trivial configuration of 'standard' mode

```puppet
include lvmconf
```

##### Install package and enable HA LVM

```puppet
class { 'lvmconf':
  systemd        => true,
  service_map    => {'metad' => 'lvm2-lvmetad'},
  manage_package => true,
  mode           => 'halvm',
  package_name   => 'lvm',
  local_vgs      => [ 'rootvg', 'nonclustervg' ],
}
```

#### Parameters

The following parameters are available in the `lvmconf` class.

##### `systemd`

Data type: `Boolean`

Indicates whether this system uses systemd or sysv as it's init system.
Different services will be manipulated depending on the value of this
parameter.

##### `service_map`

Data type: `Hash[Lvmconf::Service, String]`

A hash mapping general names of LVM services to their OS/init system
specific variants. Currently only the 'metad' entry is used directly.

Default value: {}

##### `mode`

Data type: `Lvmconf::Mode`

Configures the local LVM instance operation mode. See `man lvmconf` for more
detail.

Default value: 'standard'

##### `manage_package`

Data type: `Boolean`

When true puppet will attempt to install the lvm2 package on this host.

Default value: `false`

##### `package_name`

Data type: `Optional[String[1]]`

Name of the LVM2 package for retrieval by the local package manager on the
target system. Operating systems which are explicitly supported
have hiera configured defaults for this parameter. It is mandatory when
`manage_package` is true.

Default value: `undef`

##### `manage_initramfs`

Data type: `Boolean`

When true the local initramfs will be regenerated to take the changes to
lvm.conf into account.

Default value: `false`

##### `initramfs_type`

Data type: `Lvmconf::InitramfsType`

Indicates the type of initramfs to be modified. Currently, only dracut is
supported by this module.

Default value: 'dracut'

##### `local_vgs`

Data type: `Optional[Array[String]]`

Whitelist of local-only volume groups which will be automatically imported
by LVM. Each entry in this array will be added to the
'activation/volume_list' array in lvm.conf. This is critical when halvm or
clustered LVM are enabled.

Default value: []

### lvmconf::config

Enforces lvm.conf based on lvmconf mode flags

### lvmconf::install

Install the lvm package if specified

### lvmconf::service

Manage the state of each LVM related service based on lvmconf mode

## Resource types

### lvm_config

Type to manage entries in the `/etc/lvm/lvm.conf` config file via
the lvmconfig (aka lvm config) command.

Example:

```puppet
lvm_config { 'activation/volume_list':
  value  => [\"vg1\",\"vg2\"],
}
```

#### Properties

The following properties are available in the `lvm_config` type.

##### `value`

Data to be stored as the value for the specified
Section/Setting key. Some validation is performed by lvmconfig
during the apply process. If an error can be detected the provider
will also generate a failure during the apply.

#### Parameters

The following parameters are available in the `lvm_config` type.

##### `name`

namevar

The Section/Setting key string which corresponds to the desired
variable. See the output of `lvmconfig -l` for reference. Values are
not validated, however, the keys themselves are tested prior to creating
the entry.

##### `include_comments`

Valid values: `true`, `false`, yes, no

When true full descriptive comments will be included in the
resulting lvm config file. Note that currently this is all or nothing. If
you want to ensure comments are not included make sure you disable this
for every instance of lvm_config!

Default value: `true`

